@@ -1,8 +1,10 @@
 package HTTP::UserAgentClientHints;
 use strict;
 use warnings;
+use HTTP::UserAgentClientHints::BrandVersion;
+use HTTP::UserAgentClientHints::Util;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my $HTTP_HEADER_PREFIX = 'Sec-CH-UA';
 
@@ -60,28 +62,19 @@ sub _normalize {
 
     return $value unless defined $value;
 
-    if ($field =~ m!^(?:Platform|Arch|Bitness|Model|Full-Version)$!) {
-        $value = $self->_strip_quote($value);
+    if ($field eq 'UA' || $field eq 'Full-Version-List') {
+        $value = HTTP::UserAgentClientHints::BrandVersion->new($value);
     }
-
-    if ($field eq 'Mobile') {
+    elsif ($field =~ m!^(?:Platform|Arch|Bitness|Model|Full-Version)$!) {
+        $value = HTTP::UserAgentClientHints::Util->strip_quote($value);
+    }
+    elsif ($field eq 'Mobile') {
         $value =~ s/^\?//;
     }
 
     return $value;
 }
 
-sub _strip_quote {
-    my ($self, $value) = @_;
-
-    return '' unless defined $value;
-
-    $value =~ s/^"//;
-    $value =~ s/"$//;
-
-    return $value;
-}
-
 sub new {
     my ($class, $http_headers_obj) = @_;
 
@@ -154,11 +147,9 @@ The constructor. The $http_headers_object is required. It should be an object li
 
 These methods below are normalized to remove double-quotes around value and strip `?` on Sec-UA-CH-Mobile.
 
-B<WARNIGS>: The value of C<ua> and C<full_version_list> are not concreted. These are sama value as *_raw method for now. In the future, these would be changed to a hash reference value after parsing. 
-
 =head3 ua
 
-To get the value of Sec-CH-UA
+To get the value of Sec-CH-UA as an object of L<HTTP::UserAgentClientHints::BrandVersion>
 
 =head3 mobile
 
@@ -182,7 +173,7 @@ To get the value of Sec-CH-UA-Model
 
 =head3 full_version_list
 
-To get the value of Sec-CH-UA-Full-Version-List
+To get the value of Sec-CH-UA-Full-Version-List as an object of L<HTTP::UserAgentClientHints::BrandVersion>
 
 =head3 full_version
 
@@ -217,7 +208,7 @@ To get a string for C<Accept-CH> header in order to request UA-CH. By default, t
 
 =begin html
 
-<a href="https://github.com/bayashi/HTTP-UserAgentClientHints/blob/main/README.pod"><img src="https://img.shields.io/badge/Version-0.02-green?style=flat"></a> <a href="https://github.com/bayashi/HTTP-UserAgentClientHints/blob/main/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/HTTP-UserAgentClientHints/actions"><img src="https://github.com/bayashi/HTTP-UserAgentClientHints/workflows/main/badge.svg?_t=1644666777"/></a> <a href="https://coveralls.io/r/bayashi/HTTP-UserAgentClientHints"><img src="https://coveralls.io/repos/bayashi/HTTP-UserAgentClientHints/badge.png?_t=1644666777&branch=main"/></a>
+<a href="https://github.com/bayashi/HTTP-UserAgentClientHints/blob/main/README.pod"><img src="https://img.shields.io/badge/Version-0.03-green?style=flat"></a> <a href="https://github.com/bayashi/HTTP-UserAgentClientHints/blob/main/LICENSE"><img src="https://img.shields.io/badge/LICENSE-Artistic%202.0-GREEN.png"></a> <a href="https://github.com/bayashi/HTTP-UserAgentClientHints/actions"><img src="https://github.com/bayashi/HTTP-UserAgentClientHints/workflows/main/badge.svg?_t=1644924232"/></a> <a href="https://coveralls.io/r/bayashi/HTTP-UserAgentClientHints"><img src="https://coveralls.io/repos/bayashi/HTTP-UserAgentClientHints/badge.png?_t=1644924232&branch=main"/></a>
 
 =end html
 
@@ -235,6 +226,7 @@ Dai Okabayashi E<lt>bayashi@cpan.orgE<gt>
 
 L<https://github.com/WICG/ua-client-hints/blob/main/README.md>
 
+L<https://wicg.github.io/ua-client-hints/>
 
 =head1 LICENSE
 
